@@ -1,7 +1,11 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/common_hw/S3gendac.h,v 3.3 1995/01/20 04:21:21 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/common_hw/S3gendac.h,v 3.8 1996/10/03 08:34:25 dawes Exp $ */ 
+
+
 /* Jon Tombs <jon@esix2.us.es>  */
 
 
+/* $XConsortium: S3gendac.h /main/5 1995/11/12 19:30:20 kaleb $ */
+
 #define GENDAC_INDEX	     0x3C8
 #define GENDAC_DATA	     0x3C9
 #define BASE_FREQ         14.31818   /* MHz */
@@ -18,13 +22,13 @@ int ET4000gendacSetClock(
 #endif
 );     
 
-int ET6000SetClock( 
+int ET4000gendacSetpixmuxClock( 
 #if NeedFunctionPrototypes
    long freq, int clock
 #endif
 );     
 
-int ET4000gendacSetpixmuxClock( 
+int ET6000SetClock( 
 #if NeedFunctionPrototypes
    long freq, int clock
 #endif
@@ -36,18 +40,35 @@ int ICS5342SetClock(
 #endif
 );     
 
+/* [kmg] */
+int ARK2000gendacSetClock(
+#if NeedFunctionPrototypes
+   long freq, int clock
+#endif
+);     
+
 int S3TrioSetClock( 
 #if NeedFunctionPrototypes
    long freq, int clock
 #endif
 );     
 
-void commonCalcClock(
+int commonCalcClock(
 #if NeedFunctionPrototypes
    long freq,
-   int min_n2,
+   int min_m, int min_n, int min_n2, int max_n2,
    long freq_min, long freq_max,
    unsigned char *mdiv, unsigned char *ndiv
 #endif
 );
 
+int commonSetClock(
+#if NeedFunctionPrototypes
+   long freq, int clock,
+   int min_m, int min_n, int min_n2, int max_n2, int pll_type,
+   long freq_min, long freq_max
+#endif
+);
+
+
+
