@@ -1,6 +1,6 @@
 /*  SVGATextMode -- An SVGA textmode manipulation/enhancement tool
  *
- *  Copyright (C) 1995,1996  Koen Gadeyne
+ *  Copyright (C) 1995-1998  Koen Gadeyne
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@ typedef unsigned char byte;
  * Supported ClockChips
  */
  
-void set_clockchip_clock(int chipset, long freq);
+void set_clockchip_clock(int chipset, long freq, int charwidth);
 
 void set_clockchip_Mclock(int chipset, long freq);
 
