@@ -1,6 +1,6 @@
 /*  SVGATextMode -- An SVGA textmode manipulation/enhancement tool
  *
- *  Copyright (C) 1995,1996  Koen Gadeyne
+ *  Copyright (C) 1995-1998  Koen Gadeyne
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ int GetClock(int chipset, int freq, int *closestfreq, bool report_error);
 
 void SetClock(int chipset, int freq);
 
-void do_clock(int chipset, int clock);
+void do_clock(int chipset, int clock, int charwidth);
 
 
 #endif
