@@ -1,6 +1,6 @@
 /*  SVGATextMode -- An SVGA textmode manipulation/enhancement tool
  *
- *  Copyright (C) 1995,1996  Koen Gadeyne
+ *  Copyright (C) 1995-1998  Koen Gadeyne
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@
 #  endif
 
 #else
-   int resize_DOS(int cols, int rows);
+   int resize_DOS(int cols, int rows, int fontsize); // AB
 #endif
 
 
