@@ -1,6 +1,6 @@
 /*  SVGATextMode -- An SVGA textmode manipulation/enhancement tool
  *
- *  Copyright (C) 1995,1996  Koen Gadeyne
+ *  Copyright (C) 1995-1998  Koen Gadeyne
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -27,10 +27,13 @@
 #include "cfg_structs.h"
 #include "chipset.h"
 
+/* These limits are partly based on guessing and partly on experience ... */
+#define MAX_CLOCK_DEVIATION  1500    /* kHz */
+/* only used when one single frequency is specified in config file */
+#define MAX_HSYNC_DEVIATION   600    /* Hz */
+#define MAX_VSYNC_DEVIATION  1200    /* 1/1000 Hz */
 
-#define MAX_CLOCKDEVIATION  1500    /* kHz! */
-
-void sanitize_cfgfile_data();
+void sanitize_cfgfile_data(void);
 
 bool check_range(int checkval, t_mon_timing *p_tim);
 
